function image_FC = FC_filter(RF_frame,fL,fH,n,Nyquist_freq)
%% Frequency compound (FC) filter for RF signals (function for single frame)
% IN: RF_frame - RF frame to be filtered
%     fL - lower frequncy limit of the divided band
%     fH - upper frequncy limit of the divided band 
%     n - number of sub-bands 
%     Nyquist_freq - Nyquist frequency limit (sampling frequency/2)
% OUT: image_FC - frequency compounded ultrasound image

% IEEE TRANSACTIONS ON ULTRASONICS, FERROELECTRICS, AND FREQUENCY CONTROL, VOL. 45, NO. 1, JANUARY 1998 
% Simulation Of Ultrasound Pulse Propagation In Lossy Media Obeying A Frequency Power Law
% Ping He

%% ------------------------------------------------------------------------
B=(fH-fL)/(n-1);                                                           % Bandwidth of the sub-band
%% --Frequncy responses of filter bank ------------------------------------
N=size(RF_frame,1);                                                        % Number of points 
f_filt=0:Nyquist_freq/(N-1):Nyquist_freq;                                  % Frequency range (0...Fs/2)      

alpha_=0.47;                                                                %% Coefficient of nonlinearity
image_bits=8;
num_gray_levels=2^image_bits;                                              %% Number of gray levels to map RF data 0...num_gray_levels
ADC_bits=16;

for j=1:size(RF_frame,2)                 
%% Sub-band processing   
for i=1:n % from 1 to number of sub-bands
 
% Decomposition filters   
Bi=(1/(sqrt(pi)))*exp(-((f_filt-fL-(i-1)*B)/B).^2);
       
filtered_sig=real(ifft(fft(RF_frame(:,j)').*(Bi))); % frequency domain filtering with inverse FFT 
Subband_power(i)=mean(abs(filtered_sig.^2));                             % Subband energy calculation for weight coeficients     

%% Sub-band image formation
% Envelope detection of sub-band signal
[envelope, Q_comp]=envelope_detection(filtered_sig');            % envelope detection      

% Sub-band image formation
% Nonlinear suppression 
% Mapping to 8 BIT image 
image_N_BIT_temp(:,i)=envelope_2_image(alpha_, num_gray_levels, ADC_bits, envelope); 

end

weighting_coefficients=2*(Subband_power)/sum(Subband_power);             %% respective to subband energy (wegths each subband respective to energy)

%% Summed final frrequency compounded image 
image_FC(j,:)=sum(image_N_BIT_temp.*repmat(weighting_coefficients,size(image_N_BIT_temp,1),1),2);
end


