function image = PMAD(image, iterations, lambda, kappa)

%% IN:
% lambda, kappa - parameters of the filter
% iterations - number of iterations
%% OUT:
% image - outputs filtered B mode image

image = double(image);

% directional filters for finite differences
hN = [0 1 0; 0 -1 0; 0 0 0];
hS = [0 0 0; 0 -1 0; 0 1 0];
hE = [0 0 0; 0 -1 1; 0 0 0];
hW = [0 0 0; 1 -1 0; 0 0 0];
hNE = [0 0 1; 0 -1 0; 0 0 0];
hSE = [0 0 0; 0 -1 0; 0 0 1];
hSW = [0 0 0; 0 -1 0; 1 0 0];
hNW = [1 0 0; 0 -1 0; 0 0 0];

for t = 1:iterations

        deltaN = conv2(image,hN,'same');
        deltaS = conv2(image,hS,'same');   
        deltaW = conv2(image,hW,'same');
        deltaE = conv2(image,hE,'same');   
        deltaNE = conv2(image,hNE,'same');
        deltaSE = conv2(image,hSE,'same');   
        deltaSW = conv2(image,hSW,'same');
        deltaNW = conv2(image,hNW,'same'); 
        
        cN = 1./(1 + (deltaN/kappa).^2);
        cS = 1./(1 + (deltaS/kappa).^2);
        cW = 1./(1 + (deltaW/kappa).^2);
        cE = 1./(1 + (deltaE/kappa).^2);
        cNE = 1./(1 + (deltaNE/kappa).^2);
        cSE = 1./(1 + (deltaSE/kappa).^2);
        cSW = 1./(1 + (deltaSW/kappa).^2);
        cNW = 1./(1 + (deltaNW/kappa).^2);
     

image = image + lambda*(cN.*deltaN + cS.*deltaS + cW.*deltaW + cE.*deltaE + 0.5*cNE.*deltaNE + 0.5*cSE.*deltaSE + 0.5*cSW.*deltaSW + 0.5*cNW.*deltaNW);
           
        
        
end